pub fn process_main_thread_queue() -> boolExpand description
Processes pending callbacks queued via call_after.
This function is called automatically by the event loop. You do not need to call this function manually.
Returns true if any callbacks were processed, false if the queue was empty.