GenericDC

Struct GenericDC 

pub struct GenericDC { /* private fields */ }
A generic device context that can wrap any raw DC pointer.

Implementations

Source

impl GenericDC

pub unsafe fn from_ffi_ptr(ptr: *mut wxd_DC_t) -> Self

Create a GenericDC from a raw FFI pointer, taking ownership.

Safety

The pointer must be valid and should be destroyed by calling wxd_DC_Destroy.

pub unsafe fn from_ffi_ptr_unowned(ptr: *mut wxd_DC_t) -> Self

Create a GenericDC from a raw FFI pointer without taking ownership.

Safety

The pointer must be valid for the duration of the GenericDC’s lifetime.