PenStyle

Struct PenStyle 

pub struct PenStyle(/* private fields */);
Style flags for DC pen.

These flags can be combined using the bitwise OR operator (|).

Implementations

Source

impl PenStyle

pub const Solid: Self

Solid line style.

pub const Dot: Self

Dotted line style.

pub const LongDash: Self

Long dashed line style.

pub const ShortDash: Self

Short dashed line style.

pub const DotDash: Self

Dot and dash line style.

pub const Transparent: Self

Transparent pen.

pub const Stipple: Self

Stippled pen.

pub const UserDash: Self

User-defined dash pattern.

pub const BDiagonalHatch: Self

Backward diagonal hatch pattern.

pub const CrossDiagHatch: Self

Cross-diagonal hatch pattern.

pub const FDiagonalHatch: Self

Forward diagonal hatch pattern.

pub const CrossHatch: Self

Cross hatch pattern.

pub const HorizontalHatch: Self

Horizontal hatch pattern.

pub const VerticalHatch: Self

Vertical hatch pattern.

Source

impl PenStyle

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> i64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: i64) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: i64) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: i64) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl PenStyle

pub const fn iter(&self) -> Iter<PenStyle>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<PenStyle>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.