pub struct CalendarCtrlStyle(/* private fields */);Expand description
Style flags for Calendar control.
These flags can be combined using the bitwise OR operator (|).
Implementations
Sourceimpl CalendarCtrlStyle
impl CalendarCtrlStyle
Sourcepub const SundayFirst: Self
pub const SundayFirst: Self
Show Sunday as the first day in the week.
Sourcepub const MondayFirst: Self
pub const MondayFirst: Self
Show Monday as the first day in the week.
Sourcepub const ShowHolidays: Self
pub const ShowHolidays: Self
Highlight holidays in the calendar.
Sourcepub const NoYearChange: Self
pub const NoYearChange: Self
Disable year changing.
Sourcepub const NoMonthChange: Self
pub const NoMonthChange: Self
Disable month changing.
Sourcepub const SequentialMonthSelection: Self
pub const SequentialMonthSelection: Self
Use alternative, more compact, style for the month and year selection controls.
Sourcepub const ShowSurroundingWeeks: Self
pub const ShowSurroundingWeeks: Self
Show the neighbouring weeks in the previous and next months.
Sourceimpl CalendarCtrlStyle
impl CalendarCtrlStyle
Sourcepub const fn bits(&self) -> i64
pub const fn bits(&self) -> i64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i64) -> Option<Self>
pub const fn from_bits(bits: i64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i64) -> Self
pub const fn from_bits_truncate(bits: i64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i64) -> Self
pub const fn from_bits_retain(bits: i64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl CalendarCtrlStyle
impl CalendarCtrlStyle
Sourcepub const fn iter(&self) -> Iter<CalendarCtrlStyle>
pub const fn iter(&self) -> Iter<CalendarCtrlStyle>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CalendarCtrlStyle>
pub const fn iter_names(&self) -> IterNames<CalendarCtrlStyle>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.