pub struct GenericDC { /* private fields */ }Expand description
A generic device context that can wrap any raw DC pointer.
Implementations
Sourceimpl GenericDC
impl GenericDC
Sourcepub unsafe fn from_ffi_ptr(ptr: *mut wxd_DC_t) -> Self
pub unsafe fn from_ffi_ptr(ptr: *mut wxd_DC_t) -> Self
Create a GenericDC from a raw FFI pointer, taking ownership.
Safety
The pointer must be valid and should be destroyed by calling wxd_DC_Destroy.
Sourcepub unsafe fn from_ffi_ptr_unowned(ptr: *mut wxd_DC_t) -> Self
pub unsafe fn from_ffi_ptr_unowned(ptr: *mut wxd_DC_t) -> Self
Create a GenericDC from a raw FFI pointer without taking ownership.
Safety
The pointer must be valid for the duration of the GenericDC’s lifetime.