pub enum BackgroundStyle {
Erase,
System,
Paint,
Colour,
}Expand description
Background style for windows, affecting how background painting is handled.
Variants
Erase
The background is erased automatically by the system. This is the default for most controls and is suitable for most cases.
System
The background is erased by the system as in Erase, but using the current background color instead of the default one.
Paint
The background is not erased automatically, and the application is responsible for painting the entire background in its paint handler. This is optimal for custom drawing and animation as it prevents flicker.
Colour
Similar to Paint, but the background is filled with the background colour before calling the paint event handler.
Implementations